@@ -10,9 +10,9 @@ import allure
 from time import sleep
 from selenium.webdriver.support.wait import WebDriverWait
 from loguru import logger
-from common.base_path import _dir
+from weilaizz.templates.http_demo.common.basePath import _dir
 
-from common.runTime import _runtime
+from weilaizz.templates.http_demo.common.runTime import _runtime
 
 
 class BaseUtil():
