@@ -6,7 +6,8 @@
 
 
 import zmail
-from common._read_yaml import read_yaml
+from weilaizz.templates.http_demo.common.readYaml import read_yaml
+
 class SendEmail:
     def __init__(self, subject, content_text, *attachments):
         """构造方法，初始化邮件内容
