@@ -1,5 +1,5 @@
 from openpyxl import load_workbook
-from common.basePath import _dir
+from weilaizz.templates.http_demo.common.basePath import _dir
 
 def r_xlsx(_fname, _sname="Sheet1"):
     """
