@@ -7,15 +7,17 @@
 
 import yaml
 import os
-from common.base_path import _dir
+from weilaizz.templates.http_demo.common.basePath import _dir
 from loguru import logger
 
-def read_yaml():
+def read_yaml(key, filename=_dir + 'config/data.yaml'):
     """读取yaml文件并return文件"""
-    file_dir = _dir + '/config/cfg.yaml'.replace(r'\/'.replace(os.sep, ''), os.sep)
-    with open(file_dir, mode='r', encoding='utf-8') as file:
-        msg = yaml.load(file, Loader=yaml.FullLoader)
-    return msg
+    with open(filename, 'r', encoding='utf-8') as f:
+        data = yaml.load(f, Loader=yaml.FullLoader)
+        keys = key.split(".")
+        for k in keys:
+            data = data[k]
+        return data
 
 
 def load_yaml(file_path):
@@ -40,3 +42,10 @@ def load(file_name, path=_dir):
             return data
 
 
+
+
+
+
+
+if __name__ == '__main__':
+    print(read_yaml('url.dev'))
\ No newline at end of file
