@@ -6,7 +6,7 @@
 
 
 from ruamel import yaml
-from common.base_path import _dir
+from weilaizz.templates.http_demo.common.basePath import _dir
 
 def write_yaml_data(key, value, filename=_dir + 'config/data.yaml'):
     """
