@@ -7,11 +7,11 @@
 
 import os
 import platform
-from env import globa
-from common.base_path import _dir
-from common.clean_f import clearLog as cl, clearFile as cf
+from weilaizz.templates.http_demo.env import globa
+from weilaizz.templates.http_demo.common.basePath import _dir
+from weilaizz.templates.http_demo.common.clearFile import clearLog as cl, clearFile as cf
 from shutil import copyfile
-from env import write_env
+from weilaizz.templates.http_demo.env import write_env
 
 
 def mainSetup():
