@@ -7,7 +7,7 @@
 
 import pytest
 import allure
-from common._read_yaml import load, read_yaml_url as rdurl
+from weilaizz.templates.http_demo.common.readYaml import load, read_yaml
 from loguru import logger
 
 
@@ -19,7 +19,7 @@ from loguru import logger
 @allure.feature('登录模块')
 class TestLogin:
     udata = load('loginData.yaml')
-    url = rdurl('url.test')
+    url = read_yaml('url.test')
 
     def setup_class(self):
         logger.info(f'开始执行{TestLogin.__name__}模块测试')
